searchData={"items":[{"type":"module","title":"PhoenixImportmap","doc":"Use [ES/JS Modules](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules) with [importmap](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/script/type/importmap) to efficiently serve JavaScript without transpiling or bundling.\n\nWith this approach you'll ship many small JavaScript files instead of one big JavaScript file.\n\nImport maps are [supported natively](https://caniuse.com/?search=importmap) in all major, modern browsers.","ref":"PhoenixImportmap.html"},{"type":"module","title":"Installation - PhoenixImportmap","doc":"The package can be installed by adding `phoenix_importmap` to your list of dependencies in mix.exs:\n\n```elixir\ndef deps do\n  [\n    {:phoenix_importmap, \"~> 0.1.0\"}\n  ]\nend\n```\n\nIf you are using the esbuild package you may also remove it, along with its configuration.\n\nIn `config/dev.exs` add the asset watcher to your `Endpoint` configuration:\n\n```elixir\nwatchers: [\n  assets: {PhoenixImportmap, :copy_and_watch, [~w(/assets)]},\n]\n```\n\nIn `config/config.exs` add an importmap. The following is a good start for a conventional Phoenix app:\n\n```elixir\nconfig :phoenix_importmap, :importmap, %{\n  app: \"/assets/js/app.js\",\n  topbar: \"/assets/vendor/topbar.js\",\n  phoenix_html: \"/deps/phoenix_html/priv/static/phoenix_html.js\",\n  phoenix: \"/deps/phoenix/priv/static/phoenix.mjs\",\n  phoenix_live_view: \"/deps/phoenix_live_view/priv/static/phoenix_live_view.esm.js\"\n}\n```\n\nIf you are using topbar, replace the relative topbar import in `assets/app/app.js` with a module specifier. This asset will be resolved by our importmap:\n\n```js\nimport topbar from \"topbar\"\n```\n\nYou'll also need to replace the contents of `assets/vendor/topbar.js` with a wrapped version that supports ESM, like this [from jsDelivr](https://cdn.jsdelivr.net/npm/topbar@2.0.0/topbar.js/+esm).\n\nFinally, in `lib/ /components/layouts/root.html.heex` replace the `app.js` ` ` tag with:\n\n```html\n \n  <%= raw PhoenixImportmap.importmap() %>\n \n \n  import \"app\";\n \n```\n\nThe [phoenix_importmap_example repository](https://github.com/gilest/phoenix_importmap_example) also demonstrates configuring a newly-generated Phoenix app.","ref":"PhoenixImportmap.html#module-installation"},{"type":"module","title":"Importmap configuration - PhoenixImportmap","doc":"- `:importmap` - Map representing your assets. This is used to copy and watch files, and resolve public paths in `PhoenixImportmap.importmap()`","ref":"PhoenixImportmap.html#module-importmap-configuration"},{"type":"module","title":"Asset path configuration - PhoenixImportmap","doc":"The defaults should  work out of the box with a conventional Phoenix application. There are two global configuration options available.\n\n- `:copy_destination_path` - Where your mapped assets will be copied to. Defaults to `/priv/static/assets` which is the default path for to serve assets from.\n\n- `:public_asset_path_prefix` - The public path from which your assets are served. Defaults to `/priv/static` which is the default path for `Plug.Static` to serve `/` at.","ref":"PhoenixImportmap.html#module-asset-path-configuration"},{"type":"function","title":"PhoenixImportmap.copy_and_watch/1","doc":"Does an initial copy of assets, then starts a child process to watch for asset changes.\n\nFor use with [Phoenix.Endpoint](https://hexdocs.pm/phoenix/Phoenix.Endpoint.html) watchers.","ref":"PhoenixImportmap.html#copy_and_watch/1"},{"type":"function","title":"PhoenixImportmap.importmap/0","doc":"Returns a JSON-formatted importmap based on your application configuration.","ref":"PhoenixImportmap.html#importmap/0"},{"type":"module","title":"PhoenixImportmap.Asset","doc":"Internal functions for working with asset paths.","ref":"PhoenixImportmap.Asset.html"},{"type":"function","title":"PhoenixImportmap.Asset.dest_path/1","doc":"Determine the copy destination path for a given source path.","ref":"PhoenixImportmap.Asset.html#dest_path/1"},{"type":"function","title":"PhoenixImportmap.Asset.maybe_copy/2","doc":"Copy an asset from its `source_path` to its `dest_path`.","ref":"PhoenixImportmap.Asset.html#maybe_copy/2"},{"type":"function","title":"PhoenixImportmap.Asset.public_path/1","doc":"Determine the public  path for a given source path. This is what will appear\nin the output of `PhoenixImportmap.importmap()`.","ref":"PhoenixImportmap.Asset.html#public_path/1"},{"type":"module","title":"PhoenixImportmap.Watcher","doc":"A child-process which watches `watch_dirs` for changed files, and (if they are present in the project importmap) copies them to `:copy_destination_path`.\n\nPublic entrypoint is `PhoenixImportmap.copy_and_watch/1`.","ref":"PhoenixImportmap.Watcher.html"},{"type":"function","title":"PhoenixImportmap.Watcher.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"PhoenixImportmap.Watcher.html#child_spec/1"},{"type":"function","title":"PhoenixImportmap.Watcher.init/1","doc":"","ref":"PhoenixImportmap.Watcher.html#init/1"},{"type":"function","title":"PhoenixImportmap.Watcher.start_link/1","doc":"","ref":"PhoenixImportmap.Watcher.html#start_link/1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}